@@ -78,6 +78,7 @@ def debug():
     else:
         return version() == "unknown" and not _inside_docker()
 
+
 def log_level() -> int:
     log_levels = {
         "INFO": logging.INFO,
@@ -199,3 +200,7 @@ def database_folder() -> str:
     elif debug():
         path = "../sqlite/debug/"
     return path
+
+
+def run_checks() -> bool:
+    return debug() or testing()
