@@ -124,7 +124,10 @@ def core() -> OpenModuleCore:
 
 def shutdown_openmodule():
     global _core_thread
-    assert _core_thread, "core thread is not running, did you call init_openmodule(...)?"
+    assert _core_thread is not None, (
+        "core thread is not running, did you call init_openmodule(...)?\n"
+        "if its a testcase, maybe you forgot to call super().setUp()"
+    )
 
     current_core: OpenModuleCore = _core_thread
     _core_thread = None
@@ -132,7 +135,7 @@ def shutdown_openmodule():
     shutdown_done = threading.Event()
 
     def last_will():
-        if not shutdown_done.wait(timeout=1):
+        if not shutdown_done.wait(timeout=3):
             os._exit(99)
 
     if not (current_core.config.TESTING or current_core.config.DEBUG):
