@@ -2,12 +2,13 @@ from enum import Enum
 
 from datetime import datetime
 from dateutil import rrule, tz
+from dateutil.tz import UTC
 from dateutil.utils import default_tzinfo
 from pydantic import validator, Field
 from typing import List, Optional
 
 from openmodule import config
-from openmodule.models.base import OpenModuleModel, ZMQMessage, Gateway, timezone_validator
+from openmodule.models.base import OpenModuleModel, ZMQMessage, Gateway, timezone_validator, datetime_to_timestamp
 
 
 class MediumType(str, Enum):
@@ -41,7 +42,7 @@ class AccessRequest(OpenModuleModel):
 
 
 def check_recurrence(cls, recurrence, values, **kwargs):
-    if recurrence is not None:
+    if recurrence:
         if not values.get("duration"):
             raise ValueError("set a duration when using recurrence")
 
@@ -72,18 +73,19 @@ class Access(OpenModuleModel):
     user: str
 
     _check_recurrence = validator("recurrence", allow_reuse=True)(check_recurrence)
-    _check_start = timezone_validator("start")
-    _check_end = timezone_validator("end")
+    _tz_start = timezone_validator("start")
+    _tz_end = timezone_validator("end")
 
     def dict(self, **kwargs):
         data = super().dict(**kwargs)
-        data["start"] = data["start"].timestamp()
+        data["start"] = datetime_to_timestamp(data["start"])
         if data.get("end") is not None:
-            data["end"] = data["end"].timestamp()
+            data["end"] = datetime_to_timestamp(data["end"])
         return data
 
     def is_valid_at(self, dt, timezone):
-        dt = default_tzinfo(dt, tz.UTC)
+        if dt.tzinfo:
+            dt = dt.astimezone(UTC).replace(tzinfo=None)
         if self.recurrence:
             assert False, "recurrent accesses are not yet supported"
         else:
