@@ -1,19 +1,28 @@
+from datetime import datetime
 from enum import Enum
 
 import orjson
 import zmq
-from datetime import datetime
-from dateutil import tz
-from dateutil.utils import default_tzinfo
+from dateutil.tz import UTC
 from pydantic import Field, BaseModel, validator
 from pydantic.main import ROOT_KEY
 
+from openmodule import config
+
 
 def _donotuse(v, *, default):
     assert False, "please use json_bytes"
 
 
-class OpenModuleModel(BaseModel):
+if config.run_checks():
+    from openmodule import checks
+
+    meta_kwargs = {"metaclass": checks.CheckingOpenModuleModel}
+else:
+    meta_kwargs = {}
+
+
+class OpenModuleModel(BaseModel, **meta_kwargs):
     class Config:
         validate_assignment = True
 
@@ -37,8 +46,8 @@ class EmptyModel(OpenModuleModel):
 
 
 def _timezone_validator(cls, dt: datetime, values, **kwargs):
-    if dt:
-        return default_tzinfo(dt, tz.UTC)
+    if dt and dt.tzinfo:
+        return dt.astimezone(UTC).replace(tzinfo=None)
     else:
         return dt
 
@@ -47,18 +56,35 @@ def timezone_validator(field):
     return validator(field, allow_reuse=True)(_timezone_validator)
 
 
+_EPOCH_UTC = datetime(1970, 1, 1, tzinfo=UTC)
+_EPOCH_NAIVE = datetime(1970, 1, 1)
+
+
+def datetime_to_timestamp(dt: datetime):
+    """
+    you SHOULD use this function, as it always outputs the UTC unix timestamp, regardless
+    of the system's timezone. This is not an issue in production as all systems run UTC,
+    but while developing it creates annoying bugs
+    """
+    if dt.tzinfo is None:
+        return (dt - _EPOCH_NAIVE).total_seconds()
+    else:
+        return (dt - _EPOCH_UTC).total_seconds()
+
+
 class ZMQMessage(OpenModuleModel):
-    timestamp: datetime = Field(default_factory=datetime.now)
+    timestamp: datetime = Field(default_factory=lambda: datetime.now())
     name: str
     type: str
 
+    _tz_timestamp = timezone_validator("timestamp")
+
     def publish_on_topic(self, pub_socket: zmq.Socket, topic: bytes):
         pub_socket.send_multipart((topic, self.json_bytes()))
 
     def dict(self, **kwargs):
         data = super().dict(**kwargs)
-        if "timestamp" in data:
-            data["timestamp"] = data["timestamp"].timestamp()
+        data["timestamp"] = datetime_to_timestamp(data["timestamp"])
         return data
 
 
