@@ -72,14 +72,14 @@ class Backend:
         Checks the user in/out based on the received CountMessage
         """
         try:
+            self.log.debug(f"received a check {message.gateway.direction} messge for user {message.user}")
             if message.gateway.direction == "in":
                 self.check_in(message)
             else:
                 self.check_out(message)
-            self.log.info(f"Sending check_{message.gateway.direction} for {message.user} successful")
             return True
         except Exception as e:
-            self.log.exception(f"Sending check_{message.gateway.direction} for {message.user} failed")
+            self.log.exception(f"error in check_{message.gateway.direction} for user {message.user}")
             return False
 
     def rpc_check_access(self, request: AccessRequest, _) -> AccessResponse:
