@@ -3,13 +3,16 @@ from urllib.parse import urljoin
 import requests
 import requests_mock
 
+from openmodule_test.utils import DeveloperError
+
 
 class ApiMocker:
     host = None
 
     def __init__(self, mocker):
         self.mocker = mocker
-        assert self.host, "you need to set a host"
+        if not self.host:
+            raise DeveloperError("you need to set a host")
 
     def server_url(self, url):
         new_url = urljoin(self.host, url)
