@@ -1,7 +1,5 @@
 import random
 import string
-from typing import Type
-
 import threading
 import time
 from contextlib import suppress
@@ -32,7 +30,8 @@ class RPCServerTestMixin(ZMQTestMixin):
         channels = set(x[0] for x in server.handlers)
         random_type = "_test" + "".join(random.choices(string.ascii_letters, k=10))
         for channel in channels:
-            server.register_handler(channel, random_type, _EmptyModel, _EmptyModel, partial(handler, channel=channel))
+            server.register_handler(channel, random_type, _EmptyModel, _EmptyModel, partial(handler, channel=channel),
+                                    register_schema=False)
             pending_channels[channel] = None
 
         for x in range(self.zmq_client.startup_check_iterations):
