@@ -18,6 +18,10 @@ import time
 import zmq
 from pydantic import BaseModel, Field
 
+from openmodule.dispatcher import MessageDispatcher, SubscribingMessageDispatcher
+from openmodule.utils.schema import Schema
+from openmodule_test.utils import DeveloperError
+
 
 def patch_bind_string(bind_string: str) -> str:
     """
@@ -133,6 +137,7 @@ class TestClient(threading.Thread):
     _command_topic: bytes
     subscribed_topics: set
     pending_topics: Dict[bytes, None]
+    zmq_dispatcher: SubscribingMessageDispatcher
 
     pub: zmq.Socket = None
     sub: zmq.Socket = None
@@ -148,11 +153,16 @@ class TestClient(threading.Thread):
         self.log = logging.getLogger(self.__class__.__name__)
         self.recv_lock = threading.Lock()
         self.recv_messages = []
+        self.zmq_dispatcher = SubscribingMessageDispatcher(subscribe=self._assert_subscription,
+                                                           raise_validation_errors=True, raise_handler_errors=True)
         self.has_messages = threading.Event()
         self.receiving_thread_id = None
         self.send_lock = threading.Lock()
         self.running = True
 
+    def _assert_subscription(self, topic: bytes):
+        assert topic in self.subscribed_topics, f"please subscribe to {topic} in your testcase"
+
     def subscribe(self, *topics: bytes):
         for topic in topics:
             self.sub.subscribe(topic)
@@ -207,6 +217,7 @@ class TestClient(threading.Thread):
                                 del self.pending_topics[topic]
                         continue
 
+                self.zmq_dispatcher.dispatch(topic, message)
                 with self.recv_lock:
                     self.recv_messages.append((topic, message))
                     self.has_messages.set()
@@ -260,10 +271,11 @@ class TestClient(threading.Thread):
 
         # protect the developer from using the client in multiple threads, this is not supported
         with self.recv_lock:
-            assert self.receiving_thread_id is None, (
-                "the test client is not thread safe! you have to use a separate client for each thread which"
-                "wants to receive messages"
-            )
+            if self.receiving_thread_id is not None:
+                raise DeveloperError(
+                    "the test client is not thread safe! you have to use a separate client for each thread which"
+                    "wants to receive messages"
+                )
             self.receiving_thread_id = threading.get_ident()
 
         try:
@@ -290,12 +302,13 @@ class TestClient(threading.Thread):
         if topic and hasattr(topic, "encode"):
             topic = topic.encode()
 
-        assert topic in self.subscribed_topics, (
-            "please subscribe to the topic you want to receive from first! call:\n"
-            f'  > zmq_client.subscribe("{topic.decode()}")\n'
-            f'or set\n'
-            f'  > topics = ["{topic.decode()}"] in your test class'
-        )
+        if topic not in self.subscribed_topics:
+            raise DeveloperError(
+                "please subscribe to the topic you want to receive from first! call:\n"
+                f'  > zmq_client.subscribe("{topic.decode()}")\n'
+                f'or set\n'
+                f'  > topics = ["{topic.decode()}"] in your test class'
+            )
         return self.wait_for_message(lambda recv_topic, _: (not topic) or recv_topic == topic, timeout=timeout)[1]
 
     def stop(self):
@@ -381,6 +394,7 @@ class ZMQTestMixin(TestCase):
         received = False
 
         def handler(_):
+            """wait for dispatcher handler"""
             nonlocal received
             received = True
 
@@ -390,7 +404,7 @@ class ZMQTestMixin(TestCase):
         """
         random_topic = "_test" + "".join(random.choices(string.ascii_letters, k=10))
         random_topic = random_topic.encode()
-        dispatcher.register_handler(random_topic, BaseModel, handler)
+        dispatcher.register_handler(random_topic, BaseModel, handler, register_schema=False)
 
         for x in range(self.zmq_client.startup_check_iterations):
             self.zmq_client.send(random_topic, {"type": "connection-check"})
@@ -412,13 +426,15 @@ class ZMQTestMixin(TestCase):
         super(ZMQTestMixin, self).tearDown()
         self.zmq_client.stop()
         self.zmq_broker.stop()
+        Schema.to_file()
 
     def rpc(self, channel: str, type: str, request, timeout=3, receive_response=True) -> Optional[dict]:
         response_topic = f"rpc-rep-{channel}".encode("ascii")
-        assert response_topic in self.zmq_client.subscribed_topics, (
-            "you have to list the rpc channels you want to use beforehand. please set:\n"
-            f'  > rpc_channels = ["{channel}"] in your test class '
-        )
+        if response_topic not in self.zmq_client.subscribed_topics:
+            raise DeveloperError(
+                "you have to list the rpc channels you want to use beforehand. please set:\n"
+                f'  > rpc_channels = ["{channel}"] in your test class '
+            )
 
         rpc_id = str(uuid4())
         rpc_request = _TestRPCRequest(name="testclient", type=type, rpc_id=rpc_id, request=request)
